/*====================================================================*\

FileException.java

File exception class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package exception;

//----------------------------------------------------------------------


// IMPORTS


import java.io.File;

//----------------------------------------------------------------------


// FILE EXCEPTION CLASS


public class FileException
    extends AppException
{

////////////////////////////////////////////////////////////////////////
//  Constants
////////////////////////////////////////////////////////////////////////

    private static final    int MAX_PATHNAME_LENGTH = 160;

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public FileException( AppException.Id id,
                          File            file )
    {
        super( id );
        this.file = file;
    }

    //------------------------------------------------------------------

    public FileException( AppException.Id id,
                          File            file,
                          Throwable       cause )
    {
        super( id, cause );
        this.file = file;
    }

    //------------------------------------------------------------------

    public FileException( AppException.Id id,
                          File            file,
                          String...       substitutionStrs )
    {
        super( id, substitutionStrs );
        this.file = file;
    }

    //------------------------------------------------------------------

    public FileException( AppException.Id id,
                          File            file,
                          Throwable       cause,
                          String...       substitutionStrs )
    {
        super( id, cause, substitutionStrs );
        this.file = file;
    }

    //------------------------------------------------------------------

    public FileException( AppException exception,
                          File         file )
    {
        this( exception.getId( ), file, exception.getCause( ), exception.getSubstitutionStrings( ) );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Class methods
////////////////////////////////////////////////////////////////////////

    protected static String getPathname( File file )
    {
        return ExceptionUtilities.getLimitedPathname( file, MAX_PATHNAME_LENGTH );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : overriding methods
////////////////////////////////////////////////////////////////////////

    @Override
    protected String getPrefix( )
    {
        return ( (file == null) ? null : getPathname( ) + "\n" );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public File getFile( )
    {
        return file;
    }

    //------------------------------------------------------------------

    public String getPathname( )
    {
        return getPathname( file );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private File    file;

}

//----------------------------------------------------------------------
