/*====================================================================*\

UriException.java

URI exception class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package exception;

//----------------------------------------------------------------------


// IMPORTS


import java.net.URI;

//----------------------------------------------------------------------


// URI EXCEPTION CLASS


public class UriException
    extends AppException
{

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public UriException( AppException.Id id,
                         URI             uri )
    {
        super( id );
        this.uri = uri;
    }

    //------------------------------------------------------------------

    public UriException( AppException.Id id,
                         URI             uri,
                         Throwable       cause )
    {
        super( id, cause );
        this.uri = uri;
    }

    //------------------------------------------------------------------

    public UriException( AppException.Id id,
                         URI             uri,
                         String...       substitutionStrs )
    {
        super( id, substitutionStrs );
        this.uri = uri;
    }

    //------------------------------------------------------------------

    public UriException( AppException.Id id,
                         URI             uri,
                         Throwable       cause,
                         String...       substitutionStrs )
    {
        super( id, cause, substitutionStrs );
        this.uri = uri;
    }

    //------------------------------------------------------------------

    public UriException( AppException exception,
                         URI          uri )
    {
        this( exception.getId( ), uri, exception.getCause( ), exception.getSubstitutionStrings( ) );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : overriding methods
////////////////////////////////////////////////////////////////////////

    @Override
    protected String getPrefix( )
    {
        return ( (uri == null) ? null : uri + "\n" );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public URI getUri( )
    {
        return uri;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private URI uri;

}

//----------------------------------------------------------------------
