/*====================================================================*\

UrlException.java

URL exception class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package exception;

//----------------------------------------------------------------------


// IMPORTS


import java.net.URL;

//----------------------------------------------------------------------


// URL EXCEPTION CLASS


public class UrlException
    extends AppException
{

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public UrlException( AppException.Id id,
                         URL             url )
    {
        super( id );
        this.url = url;
    }

    //------------------------------------------------------------------

    public UrlException( AppException.Id id,
                         URL             url,
                         Throwable       cause )
    {
        super( id, cause );
        this.url = url;
    }

    //------------------------------------------------------------------

    public UrlException( AppException.Id id,
                         URL             url,
                         String...       substitutionStrs )
    {
        super( id, substitutionStrs );
        this.url = url;
    }

    //------------------------------------------------------------------

    public UrlException( AppException.Id id,
                         URL             url,
                         Throwable       cause,
                         String...       substitutionStrs )
    {
        super( id, cause, substitutionStrs );
        this.url = url;
    }

    //------------------------------------------------------------------

    public UrlException( AppException exception,
                         URL          url )
    {
        this( exception.getId( ), url, exception.getCause( ), exception.getSubstitutionStrings( ) );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : overriding methods
////////////////////////////////////////////////////////////////////////

    @Override
    protected String getPrefix( )
    {
        return ( (url == null) ? null : url + "\n" );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public URL getUrl( )
    {
        return url;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private URL url;

}

//----------------------------------------------------------------------
