/*====================================================================*\

NoYes.java

No-Yes option enumeration.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package util;

//----------------------------------------------------------------------


// NO-YES OPTION ENUMERATION


public enum NoYes
    implements StringKeyed
{

////////////////////////////////////////////////////////////////////////
//  Constants
////////////////////////////////////////////////////////////////////////

    NO
    (
        "no", "false"
    ),

    YES
    (
        "yes", "true"
    );

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    private NoYes( String... keys )
    {
        this.keys = keys;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Class methods
////////////////////////////////////////////////////////////////////////

    public static NoYes get( String key )
    {
        for ( NoYes value : values( ) )
        {
            for ( String k : value.keys )
            {
                if ( k.equals( key ) )
                    return value;
            }
        }
        return null;
    }

    //------------------------------------------------------------------

    public static NoYes get( boolean value )
    {
        return ( value ? YES : NO );
    }

    //------------------------------------------------------------------

    public static String getKey( boolean value )
    {
        return get( value ).getKey( );
    }

    //------------------------------------------------------------------

    public static String toString( boolean value )
    {
        return get( value ).toString( );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : StringKeyed interface
////////////////////////////////////////////////////////////////////////

    public String getKey( )
    {
        return keys[0];
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : overriding methods
////////////////////////////////////////////////////////////////////////

    @Override
    public String toString( )
    {
        return StringUtilities.firstCharToUpperCase( getKey( ) );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public boolean toBoolean( )
    {
        return ( (this == NO) ? false : true );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private String[]    keys;

}

//----------------------------------------------------------------------
