/*====================================================================*\

ResourceProperties.java

Resource properties class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package util;

//----------------------------------------------------------------------


// IMPORTS


import java.io.InputStream;

import java.util.Hashtable;
import java.util.Map;
import java.util.Properties;

//----------------------------------------------------------------------


// RESOURCE PROPERTIES CLASS


public class ResourceProperties
{

////////////////////////////////////////////////////////////////////////
//  Constants
////////////////////////////////////////////////////////////////////////

    private static final    String  ERROR_READING_PROPERTIES_STR    = "An error occurred when reading " +
                                                                        "the resource properties from %1 .";

////////////////////////////////////////////////////////////////////////
//  Member classes : non-inner classes
////////////////////////////////////////////////////////////////////////


    // RESOURCE PROPERTIES EXCEPTION CLASS


    public static class ResourcePropertiesException
        extends RuntimeException
    {

    ////////////////////////////////////////////////////////////////////
    //  Constructors
    ////////////////////////////////////////////////////////////////////

        private ResourcePropertiesException( String    str,
                                             Throwable cause )
        {
            super( str, cause );
        }

        //--------------------------------------------------------------

    }

    //==================================================================

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    /**
     * @throws ResourcePropertiesException
     *           if an error occurs when reading the properties from the resource.
     */

    public ResourceProperties( String pathname )
    {
        this( pathname, null );
    }

    //------------------------------------------------------------------

    /**
     * @throws ResourcePropertiesException
     *           if an error occurs when reading the properties from the resource.
     */

    public ResourceProperties( String   pathname,
                               Class<?> cls )
    {
        map = new Hashtable<String, String>( );
        try
        {
            ClassLoader classLoader = (cls == null) ? null : cls.getClassLoader( );
            InputStream inStream = (classLoader == null) ? ClassLoader.getSystemResourceAsStream( pathname )
                                                         : classLoader.getResourceAsStream( pathname );
            if ( inStream != null )
            {
                Properties properties = new Properties( );
                properties.load( inStream );
                for ( String key : properties.stringPropertyNames( ) )
                    map.put( key, properties.getProperty( key ) );
            }
        }
        catch ( Exception e )
        {
            throw new ResourcePropertiesException( StringUtilities.substitute( ERROR_READING_PROPERTIES_STR,
                                                                               pathname ),
                                                   e );
        }
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public String get( String key )
    {
        return get( key, null );
    }

    //------------------------------------------------------------------

    public String get( String key,
                       String defaultValue )
    {
        String value = map.get( key );
        if ( value == null )
            value = defaultValue;
        return value;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private Map<String, String> map;

}

//----------------------------------------------------------------------
