/*====================================================================*\

Attribute.java

XML attribute class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package xml;

//----------------------------------------------------------------------


// IMPORTS


import java.text.NumberFormat;

import org.w3c.dom.Element;

//----------------------------------------------------------------------


// XML ATTRIBUTE CLASS


public class Attribute
{

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public Attribute( String  name,
                      boolean value )
    {
        this( name, Boolean.toString( value ) );
    }

    //------------------------------------------------------------------

    public Attribute( String name,
                      int    value )
    {
        this( name, Integer.toString( value ) );
    }

    //------------------------------------------------------------------

    public Attribute( String name,
                      long   value )
    {
        this( name, Long.toString( value ) );
    }

    //------------------------------------------------------------------

    public Attribute( String name,
                      double value )
    {
        this( name, Double.toString( value ) );
    }

    //------------------------------------------------------------------

    public Attribute( String       name,
                      double       value,
                      NumberFormat format )
    {
        this( name, format.format( value ) );
    }

    //------------------------------------------------------------------

    public Attribute( String name,
                      Object value )
    {
        this( name, value.toString( ) );
    }

    //------------------------------------------------------------------

    public Attribute( String  name,
                      Object  value,
                      boolean escape )
    {
        this( name, value.toString( ), escape );
    }

    //------------------------------------------------------------------

    public Attribute( String name,
                      String value )
    {
        this.name = name;
        this.value = value;
    }

    //------------------------------------------------------------------

    public Attribute( String  name,
                      String  value,
                      boolean escape )
    {
        this( name, escape ? XmlUtilities.escape( value ) : value );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public String getName( )
    {
        return name;
    }

    //------------------------------------------------------------------

    public String getValue( )
    {
        return value;
    }

    //------------------------------------------------------------------

    public void set( Element element )
    {
        element.setAttribute( name, value );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private String  name;
    private String  value;

}

//----------------------------------------------------------------------
