/*====================================================================*\

ErrorLogger.java

XML parsing error logger class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package xml;

//----------------------------------------------------------------------


// IMPORTS


import java.util.ArrayList;
import java.util.List;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXParseException;

//----------------------------------------------------------------------


// XML PARSING ERROR LOGGER CLASS


public class ErrorLogger
    implements ErrorHandler
{

////////////////////////////////////////////////////////////////////////
//  Constants
////////////////////////////////////////////////////////////////////////

    private static final    String  ERROR_STR       = "Error";
    private static final    String  FATAL_ERROR_STR = "Fatal error";
    private static final    String  WARNING_STR     = "Warning";
    private static final    String  LINE_STR        = "Line ";

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public ErrorLogger( )
    {
        errorStrings = new ArrayList<String>( );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : ErrorHandler interface
////////////////////////////////////////////////////////////////////////

    public void error( SAXParseException exception )
    {
        append( ERROR_STR, exception );
    }

    //------------------------------------------------------------------

    public void fatalError( SAXParseException exception )
    {
        append( FATAL_ERROR_STR, exception );
    }

    //------------------------------------------------------------------

    public void warning( SAXParseException exception )
    {
        append( WARNING_STR, exception );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public boolean isEmpty( )
    {
        return errorStrings.isEmpty( );
    }

    //------------------------------------------------------------------

    public void clear( )
    {
        errorStrings.clear( );
    }

    //------------------------------------------------------------------

    public String[] getErrorStrings( )
    {
        return errorStrings.toArray( new String[errorStrings.size( )] );
    }

    //------------------------------------------------------------------

    private void append( String            typeStr,
                         SAXParseException exception )
    {
        StringBuilder buffer = new StringBuilder( 64 );
        buffer.append( LINE_STR );
        buffer.append( exception.getLineNumber( ) );
        buffer.append( ": [" );
        buffer.append( typeStr );
        buffer.append( "] " );
        buffer.append( exception.getMessage( ) );
        errorStrings.add( buffer.toString( ) );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private List<String>    errorStrings;

}

//----------------------------------------------------------------------
