/*====================================================================*\

XmlValidationException.java

XML validation exception class.

------------------------------------------------------------------------

This file is part of NlfExample, a Java application that demonstrates
the use of the uk.org.blankaspect.nlf API.
Copyright 2007-2013 Andy Morgan-Richards.

NlfExample is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package xml;

//----------------------------------------------------------------------


// IMPORTS


import exception.AppException;
import exception.ExceptionUtilities;

import java.io.File;

import java.net.URL;

//----------------------------------------------------------------------


// XML VALIDATION EXCEPTION CLASS


public class XmlValidationException
    extends AppException
{

////////////////////////////////////////////////////////////////////////
//  Constants
////////////////////////////////////////////////////////////////////////

    private static final    int MAX_PATHNAME_LENGTH = 160;

    private static final    String  FIRST_ERROR_STR = "First error (of ";

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    public XmlValidationException( AppException.Id id,
                                   File            file )
    {
        super( id );
        this.file = file;
    }

    //------------------------------------------------------------------

    public XmlValidationException( AppException.Id id,
                                   File            file,
                                   String...       errorStrings )
    {
        this( id, file );
        this.errorStrings = errorStrings;
    }

    //------------------------------------------------------------------

    public XmlValidationException( AppException.Id id,
                                   URL             url )
    {
        super( id );
        this.url = url;
    }

    //------------------------------------------------------------------

    public XmlValidationException( AppException.Id id,
                                   URL             url,
                                   String...       errorStrings )
    {
        this( id, url );
        this.errorStrings = errorStrings;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Class methods
////////////////////////////////////////////////////////////////////////

    protected static String getPathname( File file )
    {
        return ExceptionUtilities.getLimitedPathname( file, MAX_PATHNAME_LENGTH );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods : overriding methods
////////////////////////////////////////////////////////////////////////

    @Override
    protected String getPrefix( )
    {
        StringBuilder buffer = new StringBuilder( );
        if ( file != null )
        {
            buffer.append( getPathname( file ) );
            buffer.append( '\n' );
        }
        else if ( url != null )
        {
            buffer.append( url );
            buffer.append( '\n' );
        }

        return buffer.toString( );
    }

    //------------------------------------------------------------------

    @Override
    protected String getSuffix( )
    {
        StringBuilder buffer = new StringBuilder( );
        if ( (errorStrings != null) && (errorStrings.length > 0) )
        {
            buffer.append( '\n' );
            if ( errorStrings.length > 1 )
            {
                buffer.append( FIRST_ERROR_STR );
                buffer.append( errorStrings.length );
                buffer.append( "):\n" );
            }
            buffer.append( errorStrings[0] );
        }

        return buffer.toString( );
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    public String[] getErrorStrings( )
    {
        return errorStrings;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private File        file;
    private URL         url;
    private String[]    errorStrings;

}

//----------------------------------------------------------------------
