/*====================================================================*\

NlfUncheckedException.java

Nested List File unchecked exception class.

------------------------------------------------------------------------

This file is part of the Blank Aspect NLF library (Java package
uk.org.blankaspect.nlf).
Copyright 2007-2013 Andy Morgan-Richards.

The Blank Aspect NLF library is free software: you can redistribute
it and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.

\*====================================================================*/


// PACKAGE


package uk.org.blankaspect.nlf;

//----------------------------------------------------------------------


// NESTED LIST FILE UNCHECKED EXCEPTION CLASS


/**
 * An object of this class signals that an exception has occurred in a method of a class in this package.
 * Like the checked {@link NlfException NlfException}, this unchecked exception is constructed with an
 * identifier that maps to a detail message.  It is intended as a more specific replacement for a runtime
 * exception such as {@code java.lang.IllegalArgumentException} or {@code java.lang.IllegalStateException}.
 *
 * @since 1.0
 * @see   NlfException
 */

public class NlfUncheckedException
    extends RuntimeException
{

////////////////////////////////////////////////////////////////////////
//  Constructors
////////////////////////////////////////////////////////////////////////

    /**
     * Constructs an {@code NlfUncheckedException} with the specified identifier.  The identifier maps to a
     * message that is used as the exception's detail message in the constructor of {@code
     * java.lang.Exception}.
     *
     * @param id  the exception identifier.
     * @since 1.0
     */

    public NlfUncheckedException( ExceptionId id )
    {
        super( id.getMessage( ) );
        this.id = id;
    }

    //------------------------------------------------------------------

    /**
     * Constructs an {@code NlfUncheckedException} with the specified identifier and cause.  The identifier
     * maps to a message that is used as the exception's detail message in the constructor of {@code
     * java.lang.Exception}.
     *
     * @param id     the exception identifier.
     * @param cause  the {@code java.lang.Throwable} that caused this exception.
     * @since 1.0
     */

    public NlfUncheckedException( ExceptionId id,
                                  Throwable   cause )
    {
        super( id.getMessage( ), cause );
        this.id = id;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance methods
////////////////////////////////////////////////////////////////////////

    /**
     * Returns the exception identifier.
     *
     * @return the exception identifier.
     * @since  1.0
     */

    public ExceptionId getId( )
    {
        return id;
    }

    //------------------------------------------------------------------

////////////////////////////////////////////////////////////////////////
//  Instance variables
////////////////////////////////////////////////////////////////////////

    private ExceptionId id;

}

//----------------------------------------------------------------------
